@@ -14,9 +14,6 @@
 #include <KAboutData>
 #include <KCrash>
 #include <KDBusService>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QStandardPaths>
@@ -29,19 +26,9 @@
 
 int main(int argc, char* argv[])
 {
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("ksnakeduel");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("ksnakeduel"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("ksnakeduelrc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("ksnakeduelui.rc"));
-    migrate.migrate();
-#endif
 
     KAboutData aboutData( QStringLiteral("ksnakeduel"), i18n("KSnakeDuel"),
             QStringLiteral(KSNAKEDUEL_VERSION_STRING),
@@ -59,14 +46,18 @@ int main(int argc, char* argv[])
     aboutData.addAuthor(i18n("Benjamin Meyer"), i18n("Various improvements"), QStringLiteral("ben+ktron@meyerhome.net"));
     aboutData.addAuthor(i18n("Stas Verberkt"), i18n("KDE 4 Port, interface revision and KSnake mode"), QStringLiteral("legolas@legolasweb.nl"));
 
-    QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("ksnakeduel")));
+
     KCrash::initialize();
+
+    QCommandLineParser parser;
     parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("snake"), i18n("Start in KSnake mode")));
 
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
+
     KDBusService service;
 
     //KStandardDirs::locateLocal("appdata", QLatin1String( "themes/" ));
@@ -85,8 +76,6 @@ int main(int argc, char* argv[])
     KTron *ktron = new KTron();
     ktron->show();
 
-    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("ksnakeduel")));
-
     return app.exec();
 }
 
